package com.example.pruebamaps.Menu

import android.content.pm.PackageManager
import android.location.Location
import android.os.Build
import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.widget.Toast
import androidx.annotation.RequiresApi
import androidx.core.app.ActivityCompat
import com.example.pruebamaps.R
import com.google.android.gms.location.FusedLocationProviderClient
import com.google.android.gms.location.LocationServices

import com.google.android.gms.maps.CameraUpdateFactory
import com.google.android.gms.maps.GoogleMap
import com.google.android.gms.maps.OnMapReadyCallback
import com.google.android.gms.maps.SupportMapFragment
import com.google.android.gms.maps.model.BitmapDescriptorFactory
import com.google.android.gms.maps.model.LatLng
import com.google.android.gms.maps.model.Marker
import com.google.android.gms.maps.model.MarkerOptions
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response
import java.time.LocalDateTime
import java.time.format.DateTimeFormatter

class Principal : AppCompatActivity(), OnMapReadyCallback, GoogleMap.OnMarkerClickListener {

    private lateinit var fusedLocationClient : FusedLocationProviderClient

    private lateinit var lastLocation : Location

    companion object {
        private const val LOCATION_PERMISSION_REQUEST_CODE = 1
    }


    override fun onMarkerClick(p0: Marker?) = false
    private lateinit var map: GoogleMap

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_principal)
        // Obtain the SupportMapFragment and get notified when the map is ready to be used.
        val mapFragment = supportFragmentManager
            .findFragmentById(R.id.map) as SupportMapFragment
        mapFragment.getMapAsync(this)
        fusedLocationClient = LocationServices.getFusedLocationProviderClient(this)
    }

    /**
     * Manipulates the map once available.
     * This callback is triggered when the map is ready to be used.
     * This is where we can add markers or lines, add listeners or move the camera. In this case,
     * we just add a marker near Sydney, Australia.
     * If Google Play services is not installed on the device, the user will be prompted to install
     * it inside the SupportMapFragment. This method will only be triggered once the user has
     * installed Google Play services and returned to the app.
     */
    override fun onMapReady(googleMap: GoogleMap) {
        map = googleMap




        map.setOnMarkerClickListener(this)
        map.uiSettings.isZoomControlsEnabled = true
        MarcadorApi.stackClient.getMarker(15, 0).enqueue(
            object: Callback<Coordenadas> {
                override fun onFailure(call: Call<Coordenadas>, t: Throwable) {
                    t.printStackTrace()
                }

                @RequiresApi(Build.VERSION_CODES.O)
                override fun onResponse(call: Call<Coordenadas>, response: Response<Coordenadas>) {
                    if (response.isSuccessful) {
                        val listaobjetos = response.body()
                        val objetosmarkers = listaobjetos!!.features

                        for( item in objetosmarkers.indices ){

                            var name=listaobjetos.features[item].properties.nombre
                            var contacto=listaobjetos.features[item].properties.contacto
                            var comentarios=listaobjetos.features[item].properties.comentarios
                            var lat =listaobjetos.features[item].geometry.coordinates
                            map.addMarker(
                                MarkerOptions()
                                    .position(LatLng(lat[1],lat[0]))
                                    .title(name)
                                    .snippet(contacto)

                                    .icon(
                                        BitmapDescriptorFactory.fromResource(R.drawable.imgmarkernormal)
                                    )
                            )

                            map.setOnMarkerClickListener { marker ->
                                var marcador = marker.snippet
                                Toast.makeText(this@Principal, "Este es el marker $marcador", Toast.LENGTH_SHORT).show()
                                true
                            }

                        }

                    }else{

                        Toast.makeText(this@Principal, "Fallo", Toast.LENGTH_SHORT).show()
                    }
                }
            }
        )
        setUpMap()

    }
    private fun setUpMap() {
        if (ActivityCompat.checkSelfPermission(this,
                android.Manifest.permission.ACCESS_FINE_LOCATION) != PackageManager.PERMISSION_GRANTED) {
            ActivityCompat.requestPermissions(this,
                arrayOf(android.Manifest.permission.ACCESS_FINE_LOCATION), LOCATION_PERMISSION_REQUEST_CODE)
            return
        }

        map.isMyLocationEnabled = true

        fusedLocationClient.lastLocation.addOnSuccessListener(this) { location ->

            if (location != null) {

                lastLocation = location
                val currentLatLng = LatLng(location.latitude, location.longitude)

                map.animateCamera(CameraUpdateFactory.newLatLngZoom(currentLatLng, 6f))
            }
        }
    }
}
